# This package contains macros that provide functionality relating to
# Software Collections. These macros are not used in default
# Fedora builds, and should not be blindly copied or enabled.
# Specifically, the "scl" macro must not be defined in official Fedora
# builds. For more information, see:
# http://docs.fedoraproject.org/en-US/Fedora_Contributor_Documentation
# /1/html/Software_Collections_Guide/index.html

%{?scl:%scl_package rubygem-%{gem_name}}
%{!?scl:%global pkg_name %{name}}

%global gem_name foreman_remote_execution

Summary:    Plugin that brings remote execution capabilities to Foreman
Name:       %{?scl_prefix}rubygem-%{gem_name}
Version:    0.3.0.11
Release:    1%{?dist}
Group:      Applications/System
License:    GPLv3
URL:        http://github.com/theforeman/foreman_remote_execution
Source0:    http://satellite6.lab.eng.rdu2.redhat.com/pub/sources/6.2/%{gem_name}-%{version}.gem

Requires:   foreman >= 1.11.0

Requires: %{?scl_prefix_ruby}ruby(release)
Requires: %{?scl_prefix_ruby}rubygems
Requires: %{?scl_prefix}rubygem(dynflow) >= 0.8.10
Requires: %{?scl_prefix}rubygem(dynflow) < 0.9.0
Requires: %{?scl_prefix}rubygem(foreman-tasks) >= 0.7.11
Requires: %{?scl_prefix}rubygem(foreman-tasks) < 0.8.0
Requires: %{?scl_prefix}rubygem(deface)

BuildRequires: gettext
BuildRequires: foreman-plugin >= 1.11.0
BuildRequires: foreman-assets
BuildRequires: %{?scl_prefix_ruby}ruby(release)
BuildRequires: %{?scl_prefix_ruby}rubygems-devel
BuildRequires: %{?scl_prefix_ruby}rubygems
BuildRequires: %{?scl_prefix}rubygem(dynflow) >= 0.8.10
BuildRequires: %{?scl_prefix}rubygem(dynflow) < 0.9.0
BuildRequires: %{?scl_prefix}rubygem(foreman-tasks) >= 0.7.11
BuildRequires: %{?scl_prefix}rubygem(foreman-tasks) < 0.8.0
BuildRequires: %{?scl_prefix}rubygem(deface)

BuildArch: noarch

Provides: %{?scl_prefix}rubygem(%{gem_name}) = %{version}
Provides: foreman-plugin-remote_execution
%{?scl:Obsoletes: ruby193-rubygem-%{gem_name}}

%description
A plugin bringing remote execution to the Foreman, completing the config
management functionality with remote management functionality

%package doc
BuildArch:  noarch
Requires:   %{?scl_prefix}%{pkg_name} = %{version}-%{release}
%{?scl:Obsoletes: ruby193-rubygem-%{gem_name}-doc}
Summary:    Documentation for rubygem-%{gem_name}

%description doc
This package contains documentation for rubygem-%{gem_name}.

%prep
%setup -n %{pkg_name}-%{version} -q -c -T
mkdir -p .%{gem_dir}
%{?scl:scl enable %{scl} "}
gem install --local --install-dir .%{gem_dir} \
            --force %{SOURCE0} --rdoc
%{?scl:"}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* %{buildroot}%{gem_dir}/

#build locale files
pushd %{buildroot}/%{gem_instdir}
make -C locale all-mo
popd

%{foreman_bundlerd_file}
%foreman_precompile_plugin -a -s

%posttrans
%{foreman_db_migrate}
%{foreman_db_seed}
%{foreman_apipie_cache}
%{foreman_restart}
exit 0

%files
%dir %{gem_instdir}
%exclude %{gem_instdir}/.*
%exclude %{gem_instdir}/%{gem_name}.gemspec
%exclude %{gem_instdir}/Gemfile
%{gem_instdir}/app
%{gem_instdir}/config
%{gem_instdir}/db
%{gem_instdir}/locale
%{gem_instdir}/lib
%{gem_instdir}/public
%{gem_spec}
%{foreman_bundlerd_plugin}
%{foreman_apipie_cache_foreman}
%{foreman_apipie_cache_plugin}
%{foreman_assets_plugin}
%{gem_instdir}/Rakefile
%doc %{gem_instdir}/LICENSE
%exclude %{gem_cache}
%exclude %{gem_instdir}/test

%files doc
%doc %{gem_docdir}
%doc %{gem_instdir}/doc
%doc %{gem_instdir}/README.md

%changelog
* Mon Jun 27 2016 Zach Huntington-Meath <zhunting@redhat.com> 0.3.0.11-1
- BZ #1335300 - Features are not being associated correctly to job template

* Fri Jun 17 2016 Zach Huntington-Meath <zhunting@redhat.com> 0.3.0.10-1
- BZ #1344030 - Job invocation failed with "malformed format string - %w

* Wed Jun 15 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.9-2
- Build mo files during plugin RPM build (ericdhelms@gmail.com)

* Thu May 26 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.9-1
- BZ #1337920 - Pull in the translations for snap 13

* Mon May 16 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.8-1
- BZ #1335664 - Pull in the translations for snap 12.

* Tue May 10 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.6-1
- BZ #1332228 - End time for recurring logics is not being save

* Tue May 03 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.5-1
- BZ #1325952 - Metadata isn't imported when uploading a template for remote execution
- BZ #1324506 - Don't truncate template names on 32 characters

* Wed Apr 13 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.4-1
- BZ #1324616 - Reuse foreman's core documentation helper

* Wed Apr 06 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.3-1
- BZ #1322565 - automatic locale translation

* Mon Mar 21 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.2-1
- 

* Sun Mar 06 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.1-1
- 

* Fri Feb 19 2016 Eric D Helms <ericdhelms@gmail.com> 0.3.0.0-1
- new package built with tito

* Mon Jan 25 2016 Dominic Cleal <dcleal@redhat.com> 0.2.2-1
- Release foreman_remote_execution 0.2.2 (stbenjam@redhat.com)

* Mon Jan 25 2016 Dominic Cleal <dcleal@redhat.com> 0.2.1-1
- Release foreman_remote_execution 0.2.1 (stbenjam@redhat.com)
- Update dependencies to ror SCL (dcleal@redhat.com)
- Replace ruby(abi) for ruby22 rebuild (dcleal@redhat.com)

* Fri Nov 13 2015 Dominic Cleal <dcleal@redhat.com> 0.1.1-1
- Update foreman_remote_execution to 0.1.1 (stbenjam@redhat.com)

* Mon Oct 12 2015 Dominic Cleal <dcleal@redhat.com> 0.0.10-1
- Update foreman_remote_execution to 0.0.10 (inecas@redhat.com)

* Tue Oct 06 2015 Dominic Cleal <dcleal@redhat.com> 0.0.7-1
- Release foreman_remote_execution 0.0.7 (stbenjam@redhat.com)

* Mon Sep 14 2015 Dominic Cleal <dcleal@redhat.com> 0.0.6-1
- Release foreman_remote_execution 0.0.6 (stbenjam@redhat.com)

* Wed Sep 02 2015 Dominic Cleal <dcleal@redhat.com> 0.0.5-1
- Release Remote Execution Plugins 0.0.5 (stbenjam@redhat.com)

* Thu Aug 27 2015 Dominic Cleal <dcleal@redhat.com> 0.0.4-1
- Release foreman_remote_execution 0.0.4 (stbenjam@redhat.com)

* Thu Aug 27 2015 Dominic Cleal <dcleal@redhat.com> 0.0.3-2
- Converted to tfm SCL (dcleal@redhat.com)

* Tue Aug 25 2015 Dominic Cleal <dcleal@redhat.com> 0.0.3-1
- Release foreman_remote_execution 0.0.3 (stbenjam@redhat.com)

* Tue Aug 18 2015 Stephen Benjamin <stephen@redhat.com> 0.0.2-1
- Initial release of 0.0.2
